pub struct Capabilities(/* 私有字段 */);实现
源代码impl Capabilities
impl Capabilities
pub const DRAW_HORIZ_BAND: Self
pub const DR1: Self
pub const DELAY: Self
pub const SMALL_LAST_FRAME: Self
pub const EXPERIMENTAL: Self
pub const CHANNEL_CONF: Self
pub const FRAME_THREADS: Self
pub const SLICE_THREADS: Self
pub const PARAM_CHANGE: Self
pub const OTHER_THREADS: Self
pub const VARIABLE_FRAME_SIZE: Self
源代码impl Capabilities
impl Capabilities
源代码pub const fn bits(&self) -> c_uint
pub const fn bits(&self) -> c_uint
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
源代码pub const fn from_bits(bits: c_uint) -> Option<Self>
pub const fn from_bits(bits: c_uint) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
源代码pub const fn from_bits_truncate(bits: c_uint) -> Self
pub const fn from_bits_truncate(bits: c_uint) -> Self
Convert from a bits value, unsetting any unknown bits.
源代码pub const fn from_bits_retain(bits: c_uint) -> Self
pub const fn from_bits_retain(bits: c_uint) -> Self
Convert from a bits value exactly.
源代码pub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
源代码pub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
源代码pub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
源代码pub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
源代码pub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
源代码pub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
源代码pub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
源代码pub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
源代码pub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
源代码impl Capabilities
impl Capabilities
源代码pub const fn iter(&self) -> Iter<Capabilities>
pub const fn iter(&self) -> Iter<Capabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
源代码pub const fn iter_names(&self) -> IterNames<Capabilities>
pub const fn iter_names(&self) -> IterNames<Capabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
trait 实现
源代码impl Binary for Capabilities
impl Binary for Capabilities
源代码impl BitAnd for Capabilities
impl BitAnd for Capabilities
源代码impl BitAndAssign for Capabilities
impl BitAndAssign for Capabilities
源代码fn bitand_assign(&mut self, other: Self)
fn bitand_assign(&mut self, other: Self)
The bitwise and (&) of the bits in self and other.
源代码impl BitOr for Capabilities
impl BitOr for Capabilities
源代码fn bitor(self, other: Capabilities) -> Self
fn bitor(self, other: Capabilities) -> Self
The bitwise or (|) of the bits in self and other.
源代码type Output = Capabilities
type Output = Capabilities
| operator.源代码impl BitOrAssign for Capabilities
impl BitOrAssign for Capabilities
源代码fn bitor_assign(&mut self, other: Self)
fn bitor_assign(&mut self, other: Self)
The bitwise or (|) of the bits in self and other.
源代码impl BitXor for Capabilities
impl BitXor for Capabilities
源代码impl BitXorAssign for Capabilities
impl BitXorAssign for Capabilities
源代码fn bitxor_assign(&mut self, other: Self)
fn bitxor_assign(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
源代码impl Clone for Capabilities
impl Clone for Capabilities
源代码fn clone(&self) -> Capabilities
fn clone(&self) -> Capabilities
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source 执行拷贝赋值。 阅读更多源代码impl Debug for Capabilities
impl Debug for Capabilities
源代码impl Extend<Capabilities> for Capabilities
impl Extend<Capabilities> for Capabilities
源代码fn extend<T: IntoIterator<Item = Self>>(&mut self, iterator: T)
fn extend<T: IntoIterator<Item = Self>>(&mut self, iterator: T)
The bitwise or (|) of the bits in each flags value.
源代码fn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)源代码fn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)源代码impl Flags for Capabilities
impl Flags for Capabilities
源代码const FLAGS: &'static [Flag<Capabilities>]
const FLAGS: &'static [Flag<Capabilities>]
源代码fn from_bits_retain(bits: c_uint) -> Capabilities
fn from_bits_retain(bits: c_uint) -> Capabilities
源代码fn all_named() -> Capabilities
fn all_named() -> Capabilities
源代码fn known_bits(&self) -> Self::Bits
fn known_bits(&self) -> Self::Bits
源代码fn unknown_bits(&self) -> Self::Bits
fn unknown_bits(&self) -> Self::Bits
源代码fn contains_unknown_bits(&self) -> bool
fn contains_unknown_bits(&self) -> bool
true if any unknown bits are set.源代码fn from_bits_truncate(bits: Self::Bits) -> Self
fn from_bits_truncate(bits: Self::Bits) -> Self
源代码fn from_name(name: &str) -> Option<Self>
fn from_name(name: &str) -> Option<Self>
源代码fn iter_names(&self) -> IterNames<Self>
fn iter_names(&self) -> IterNames<Self>
源代码fn iter_defined_names() -> IterDefinedNames<Self>
fn iter_defined_names() -> IterDefinedNames<Self>
Self::FLAGS.源代码fn iter_equal_names(&self) -> IterEqualNames<Self>
fn iter_equal_names(&self) -> IterEqualNames<Self>
源代码fn intersects(&self, other: Self) -> boolwhere
Self: Sized,
fn intersects(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.源代码fn contains(&self, other: Self) -> boolwhere
Self: Sized,
fn contains(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.源代码fn insert(&mut self, other: Self)where
Self: Sized,
fn insert(&mut self, other: Self)where
Self: Sized,
|) of the bits in self and other.源代码fn toggle(&mut self, other: Self)where
Self: Sized,
fn toggle(&mut self, other: Self)where
Self: Sized,
^) of the bits in self and other.源代码fn intersection(self, other: Self) -> Self
fn intersection(self, other: Self) -> Self
&) of the bits in self and other.源代码fn difference(self, other: Self) -> Self
fn difference(self, other: Self) -> Self
源代码fn symmetric_difference(self, other: Self) -> Self
fn symmetric_difference(self, other: Self) -> Self
^) of the bits in self and other.源代码fn complement(self) -> Self
fn complement(self) -> Self
!) of the bits in self, truncating the result.源代码impl FromIterator<Capabilities> for Capabilities
impl FromIterator<Capabilities> for Capabilities
源代码fn from_iter<T: IntoIterator<Item = Self>>(iterator: T) -> Self
fn from_iter<T: IntoIterator<Item = Self>>(iterator: T) -> Self
The bitwise or (|) of the bits in each flags value.
源代码impl IntoIterator for Capabilities
impl IntoIterator for Capabilities
源代码impl LowerHex for Capabilities
impl LowerHex for Capabilities
源代码impl Not for Capabilities
impl Not for Capabilities
源代码impl Octal for Capabilities
impl Octal for Capabilities
源代码impl PartialEq for Capabilities
impl PartialEq for Capabilities
源代码impl PublicFlags for Capabilities
impl PublicFlags for Capabilities
源代码impl Sub for Capabilities
impl Sub for Capabilities
源代码fn sub(self, other: Self) -> Self
fn sub(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
源代码type Output = Capabilities
type Output = Capabilities
- operator.源代码impl SubAssign for Capabilities
impl SubAssign for Capabilities
源代码fn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.